summaryrefslogtreecommitdiff
path: root/Userland/Applications/FileManager
diff options
context:
space:
mode:
Diffstat (limited to 'Userland/Applications/FileManager')
-rw-r--r--Userland/Applications/FileManager/main.cpp8
1 files changed, 6 insertions, 2 deletions
diff --git a/Userland/Applications/FileManager/main.cpp b/Userland/Applications/FileManager/main.cpp
index c2f17ea74a..e0384a2333 100644
--- a/Userland/Applications/FileManager/main.cpp
+++ b/Userland/Applications/FileManager/main.cpp
@@ -98,8 +98,9 @@ int main(int argc, char** argv)
// our initial location is defined as, in order of precedence:
// 1. the command-line path argument (e.g. FileManager /bin)
// 2. the user's home directory
// 3. the root directory
if (!initial_location.is_empty()) {
if (!ignore_path_resolution)
@@ -110,6 +111,9 @@ int main(int argc, char** argv)
}
if (initial_location.is_empty())
+ initial_location = Core::File::current_working_directory();
+
+ if (initial_location.is_empty())
initial_location = Core::StandardPaths::home_directory();
if (initial_location.is_empty())
@@ -98,8 +98,9 @@ int main(int argc, char** argv)
// our initial location is defined as, in order of precedence:
// 1. the command-line path argument (e.g. FileManager /bin)
- // 2. the user's home directory
- // 3. the root directory
+ // 2. the current directory
+ // 3. the user's home directory
+ // 4. the root directory
if (!initial_location.is_empty()) {
if (!ignore_path_resolution)